@@ -40,12 +40,21 @@ Digest::~Digest()
 	release();
 }
 
+bool Digest::is(const char *id)
+{
+	return (EVP_get_digestbyname(id) != NULL);
+}
+
 void Digest::set(const char *type)
 {
 	secure::init();
 
 	release();
 
+	// never use sha0
+	if(ieq(type, "sha"))
+		type = "sha1";
+
 	hashtype = (void *)EVP_get_digestbyname(type);
 	if(hashtype) {
 		context = new EVP_MD_CTX;
